common

package
v1.5.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 7, 2026 License: GPL-3.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckPassword

func CheckPassword(storedPassword string, password string) (bool, bool)

func DiffUintArray

func DiffUintArray(a []uint, b []uint) []uint

Find different elements in two slices Returns elements in 'a' that are not in 'b' and elements in 'b' that are not in 'a'

func EqualizeLoginTiming added in v1.5.7

func EqualizeLoginTiming(password string)

EqualizeLoginTiming performs a throwaway bcrypt comparison so that an unknown-username login costs roughly the same as a known-username/wrong-password login. The result is intentionally discarded; call it on the not-found path.

func HashPassword

func HashPassword(password string) (string, error)

func IsPasswordHash

func IsPasswordHash(password string) bool

func NewError

func NewError(a ...interface{}) error

func NewErrorf

func NewErrorf(format string, a ...interface{}) error

func Random

func Random(n int) string

func RandomInt

func RandomInt(n int) int

func UnionUintArray

func UnionUintArray(a []uint, b []uint) []uint

UnionUintArray returns a new unique slice that contains all elements from both input slices

Types

This section is empty.

Jump to